# Pyrite
Library of various utilities that I use in my programmes.

# Current corpus
- `each`: Function that creates an "each" container, whic is a container that applies any operation performed on it to each of its items.

# Future corpus
- `Registry`: Efficiently manage and track collections of same-type objects.


